<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+273"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translation>インチ</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translation>フィート</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translation>マイル</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translation>ミリメートル</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translation>センチメートル</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translation>メートル</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translation>キロメートル</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translation>マイクロインチ</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translation>ミル</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translation>ヤード</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translation>オングストローム</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translation>ナノメートル</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translation>ミクロン</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translation>デシメートル</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translation>デカメートル</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translation>ヘクトメートル</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translation>ギガメートル</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translation>アストロ</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translation>光年</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translation>パーセク</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+287"/>
        <source>By Layer</source>
        <translation>画層による</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>ブロックによる</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translation>赤</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Yellow</source>
        <translation>黄</translation>
    </message>
    <message>
        <location line="-4"/>
        <source>Green</source>
        <translation>緑</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Cyan</source>
        <translation>シアン</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Blue</source>
        <translation>青</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Magenta</source>
        <translation>マゼンタ</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orange</source>
        <translation>炎色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>ダークレッド</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>ダークグリーン</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>ダークブルー</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>暗いシアン</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>暗いマジェンダ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>暗い黄</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translation>黒</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>White</source>
        <translation>白</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Gray</source>
        <translation>灰色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translation>明るい灰色</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Others...</source>
        <translation>その他...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+45"/>
        <source>Current Layer ID</source>
        <translation>現在のレイヤー</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>図面単位</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>ラインタイプスケール</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>寸法のフォント</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <source>Referenced Block</source>
        <translation type="obsolete">参照ブロック</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+93"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+73"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+65"/>
        <source>Pixel Unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+82"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+72"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>原点</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>レイアウト</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
        <source>Scale</source>
        <translation>スケール</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation>列</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation>行</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation>列間隔</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation>行間</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+87"/>
        <location filename="../src/core/RObject.cpp" line="+66"/>
        <source>Type</source>
        <translation>タイプ</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-14"/>
        <source>Block</source>
        <translation>ブロック</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+1"/>
        <source>Block ID</source>
        <translatorcomment>never shown to user</translatorcomment>
        <translation>Block ID</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer</source>
        <translation>画層</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+99"/>
        <source>Linetype</source>
        <translation>ラインタイプ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>ラインタイプスケール</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translation>ラインの太さ</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translation>色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>表示される色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translation>描画順序</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>境界</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>下端</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+108"/>
        <source>Custom</source>
        <translation>カスタム</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>ハンドル</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>保護されています</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+2"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>幅</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <location line="+0"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>高さ</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>シンプル</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>テキスト位置</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>テキスト</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>プレーンテキスト</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>フォント名</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>テキストの高さ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>テキスト角度</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>拡大縮小 X</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>太字</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>斜体</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>行間隔</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>位置合わせ</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>水平</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>垂直</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>回転</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation>オン</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>中央に表示</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation>対象を表示</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation>全体</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-6"/>
        <location filename="../src/core/RLayer.cpp" line="-8"/>
        <location filename="../src/core/RLayout.cpp" line="-24"/>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>隠す</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Off</source>
        <translation>オフ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>凍結・変更不可</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>ロック</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Tab Order</source>
        <translation>タブ順序</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation>最小値制限</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation>最大値制限</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation>挿入基部</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation>最小範囲</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation>最大範囲</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+627"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>回状（再起的）ブロック参照が検出されました:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>ブロック名:</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+184"/>
        <source>Requires selection</source>
        <translation>選択が必要です</translation>
    </message>
</context>
<context>
    <name>RLayer</name>
    <message>
        <source>Name</source>
        <translation type="vanished">画層名</translation>
    </message>
    <message>
        <source>Frozen</source>
        <translation type="vanished">凍結</translation>
    </message>
    <message>
        <source>Locked</source>
        <translation type="vanished">ロック</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">色</translation>
    </message>
    <message>
        <source>Linetype</source>
        <translation type="vanished">ラインタイプ</translation>
    </message>
    <message>
        <source>Lineweight</source>
        <translation type="vanished">ラインの太さ</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <source>By Layer</source>
        <translation type="vanished">画層による</translation>
    </message>
    <message>
        <source>By Block</source>
        <translation type="vanished">ブロックによる</translation>
    </message>
    <message>
        <source>Continuous</source>
        <translation type="vanished">連続</translation>
    </message>
    <message>
        <source>Dot</source>
        <translation type="vanished">点</translation>
    </message>
    <message>
        <source>Dot (small)</source>
        <translation type="vanished">点（小）</translation>
    </message>
    <message>
        <source>Dot (large)</source>
        <translation type="vanished">点（大）</translation>
    </message>
    <message>
        <source>Dash</source>
        <translation type="vanished">ダッシュ</translation>
    </message>
    <message>
        <source>Dash (small)</source>
        <translation type="vanished">ダッシュ（小）</translation>
    </message>
    <message>
        <source>Dash (large)</source>
        <translation type="vanished">ダッシュ（大）</translation>
    </message>
    <message>
        <source>Dash Dot</source>
        <translation type="vanished">ダッシュドット</translation>
    </message>
    <message>
        <source>Dash Dot (small)</source>
        <translation type="vanished">ダッシュドット（小）</translation>
    </message>
    <message>
        <source>Dash Dot (large)</source>
        <translation type="vanished">ダッシュドット（大）</translation>
    </message>
    <message>
        <source>Divide</source>
        <translation type="vanished">分割</translation>
    </message>
    <message>
        <source>Divide (small)</source>
        <translation type="vanished">分割（小）</translation>
    </message>
    <message>
        <source>Divide (large)</source>
        <translation type="vanished">分割（大）</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">センター</translation>
    </message>
    <message>
        <source>Center (small)</source>
        <translation type="vanished">センター（小）</translation>
    </message>
    <message>
        <source>Center (large)</source>
        <translation type="vanished">センター（大）</translation>
    </message>
    <message>
        <source>Border</source>
        <translation type="vanished">ボーダー</translation>
    </message>
    <message>
        <source>Border (small)</source>
        <translation type="vanished">ボーダー（小）</translation>
    </message>
    <message>
        <source>Border (large)</source>
        <translation type="vanished">ボーダー（大）</translation>
    </message>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+48"/>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>詳細</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>メートル法</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>パターン</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+856"/>
        <source>By Layer</source>
        <translation>画層による</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>ブロックによる</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>連続</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>ボーダー</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>センター</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>一点鎖線</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>ダッシュ</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>二点鎖線</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>点</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>隠す</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>ファントム</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>ISOダッシュ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>ISOダッシュスペース</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>ISOロングダッシュドット</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>ISOロングダッシュダブルドット</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>ISOロングダッシュトリプルドット</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>ISOドット</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>ISOロングダッシュショートダッシュ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>ISOロングダッシュダブルショートダッシュ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>ISOダッシュドット</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>ISOダブルダッシュドット</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>ISOダッシュダブルドット</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>ISOダブルダッシュダブルドット</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>ISOダッシュトリプルドット</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>ISOダブルダッシュトリプルドット</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>給湯</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>湯</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>ガスライン</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>バッティング</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>ジグザグ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>トラック</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>フェンスライン1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>フェンスライン2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drainage</source>
        <translation>排水</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation>排水逆勾配</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+35"/>
        <source>By Layer</source>
        <translation>画層による</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>ブロックによる</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translation>デフォルト</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translation>0.00mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translation>0.05mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translation>0.09mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translation>0.13mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translation>0.15mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translation>0.18mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translation>0.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translation>0.25mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translation>0.30mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translation>0.35mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translation>0.40mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translation>0.50mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translation>0.53mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translation>0.60mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translation>0.70mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translation>0.80mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translation>0.90mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translation>1.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translation>1.06mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translation>1.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translation>1.40mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translation>1.58mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translation>2.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translation>2.11mm</translation>
    </message>
</context>
<context>
    <name>RObject</name>
    <message>
        <source>Custom</source>
        <translation type="vanished">カスタム</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="obsolete">タイプ</translation>
    </message>
    <message>
        <source>Handle</source>
        <translation type="vanished">ハンドル</translation>
    </message>
</context>
</TS>
